<template>
  <el-dialog
    width="80%"
    title="零件"
    top="5vh"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    :visible.sync="innerVisible"
    class="part-dialog"
  >
    <ttable
      :table="table"
      @row-click="rowClick"
      @current-change="handleCurrentChange"
      :isShowHide="true"
      :prelang="prelang"
      :options="options"
      :bottomOffset="255"
      :ajaxFun="ajaxFun"
      ref="partTable"
    >
      <template #toolbar></template>
    </ttable>
    <span slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取消</el-button>
      <el-button type="primary" @click="dataFormSubmit()">确定</el-button>
    </span>
  </el-dialog>
</template>

<script>
import { fetchList } from '@/api/basic/part'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '../../../api/admin/dict'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      ajaxFun: fetchList,
      innerVisible: false,
      currentRow: null,
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' },
        cancelRunCreated: true
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件号
          {
            minWidth: '30',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 名称
          {
            minWidth: '120',
            prop: 'partName',
            label: '名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件类型
          {
            minWidth: '140',
            prop: 'materialType',
            label: '零件类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getMaterialTypeType,
            optList: () => {
              return this.getMaterialTypeList()
            }
          },
          // 单位
          {
            minWidth: '120',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getUnit,
            optList: () => {
              return this.getUnitList()
            }
          },
          // 单位
          {
            minWidth: '120',
            prop: 'sunit',
            label: '单位2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getUnit,
            optList: () => {
              return this.getUnitList()
            }
          },
          // 描述
          {
            minWidth: '140',
            prop: 'description',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 一级分类
          {
            minWidth: '120',
            prop: 'assortment',
            label: '一级分类',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getAssortment()
            }
          },
          // 二级分类
          {
            minWidth: '140',
            prop: 'category',
            label: '二级分类',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getCategory()
            }
          },
          // 三级分类
          {
            minWidth: '140',
            prop: 'threeLevelClassification',
            label: '三级分类',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getThreeLevelClassification()
            }
          },
          // 规格
          {
            minWidth: '140',
            prop: 'specs',
            label: '规格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 型号
          {
            minWidth: '140',
            prop: 'partModel',
            label: '型号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 电压等级
          {
            minWidth: '140',
            prop: 'voltageLevel',
            label: '电压等级',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 特性代号1
          {
            minWidth: '140',
            prop: 'characteristic1',
            label: '特性代号1',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 特性代号2
          {
            minWidth: '140',
            prop: 'characteristic2',
            label: '特性代号2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 特性代号3
          {
            minWidth: '140',
            prop: 'characteristic3',
            label: '特性代号3',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // IFS启用批次管理
          {
            minWidth: '140',
            prop: 'lotTrackingIfs',
            label: 'IFS启用批次管理',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatLotTrackingIfs,
            optList: () => {
              return this.lotTrackingIfsOptions
            }
          },
          // 版本号
          {
            minWidth: '140',
            prop: 'engChgLevel',
            label: '版本号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 计划方法
          {
            minWidth: '140',
            prop: 'planningMethod',
            label: '计划方法',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatPlanningMethodIfs,
            optList: () => {
              return this.planningMethodOptions
            }
          },
          // 图号
          {
            minWidth: '140',
            prop: 'drawingNumber',
            label: '图号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // EAN编码
          {
            minWidth: '120',
            prop: 'ean',
            label: 'EAN编码',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件族
          {
            minWidth: '120',
            prop: 'partFamilyName',
            label: '零件族',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      },
      unitList: [],
      materialTypeList: [],
      categoryList: [],
      assortmentList: [],
      lotTrackingIfsOptions: [
        { value: false, label: '否' },
        { value: true, label: '是' }
      ],
      planningMethodOptions: [],
      threeLevelClassificationOptions: []
    }
  },
  components: {
    ttable
  },
  created() {
    this.getUnitType('unit')
    this.getMaterialType('material_type')
    this.getCategoryType('category')
    this.getAssortmentType('assortment')
    this.getPlanningMethodType('planning_method_type')
    this.getThreeLevelClassificationType('three_classification_type')
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          setTimeout(() => {
            this.getData()
          }, 100)
        })
      }
    }
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$nextTick(() => {
        this.$refs.partTable.getDataList()
      })
    },
    /**
     * 获取字典显示名称并缓存
     */
    getUnitType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.unitList = _data
        }
      })
    },
    getMaterialType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.materialTypeList = _data
        }
      })
    },
    getCategoryType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.categoryList = _data
        }
      })
    },
    getAssortmentType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.assortmentList = _data
        }
      })
    },
    getPlanningMethodType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.planningMethodOptions = _data
        }
      })
    },
    getThreeLevelClassificationType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.threeLevelClassificationOptions = _data
        }
      })
    },
    getUnit(row, column, cellValue) {
      this.unitList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getMaterialTypeType(row, column, cellValue) {
      this.materialTypeList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 单位下拉框查询
    getUnitList() {
      return this.unitList
    },
    // 零件类型下拉框查询
    getMaterialTypeList() {
      return this.materialTypeList
    },
    // 二级分类下拉框查询
    getCategory() {
      return this.categoryList
    },
    // 二级分类下拉框查询
    getAssortment() {
      return this.assortmentList
    },
    // 三级分类下拉框查询
    getThreeLevelClassification() {
      return this.threeLevelClassificationOptions
    },
    formatLotTrackingIfs(row, column, cellValue) {
      this.lotTrackingIfsOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    formatPlanningMethodIfs(row, column, cellValue) {
      this.planningMethodOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label + '、 ' + obj.description
        }
      })
      return cellValue
    },
    handleCurrentChange(val) {
      this.currentRow = val
    },
    rowClick(row) {
      this.currentRow = row
    },
    dataFormSubmit() {
      if (this.currentRow == null) {
        this.$message.error('请选择零件')
        return
      }
      this.$emit('listenToPartEvent', this.currentRow)
      this.innerVisible = false
    }
  }
}
</script>
